use bevy_ecs::prelude::*;
use egui::Key;
use egui_glow::EguiGlow;
use std::collections::HashMap;
use std::sync::Arc;
use winit::event;
pub struct Gui {
    egui_ctx: EguiGlow,
    menus: MenuManager,
    window: Arc<winit::window::Window>,
}

impl Gui {
    pub fn new(ctx: EguiGlow, window: Arc<winit::window::Window>) -> Self {
        let mut menus = MenuManager::new();

        menus.add(Menu::Hello);
        Self {
            egui_ctx: ctx,
            menus,
            window,
        }
    }

    pub fn passEvent(&mut self, event: &event::WindowEvent) -> bool {
        self.egui_ctx.on_event(event).consumed
    }

    pub fn run(&mut self, world: &mut World) {
        let mut to_be_removed = Vec::new();

        self.egui_ctx.run(&self.window, |ctx| {
            for (key, value) in &mut self.menus.0.iter_mut() {
                match value {
                    Menu::Hello => {
                        if hellotest(ctx) {
                            to_be_removed.push(*key);
                        }
                    }
                    Menu::Second => (),
                }
            }
        });
        for remove in to_be_removed {
            self.menus.0.remove(&remove);
        }

        self.egui_ctx.paint(&self.window);
    }
}

#[derive(PartialEq)]
pub enum Menu {
    Hello,
    Second,
}

fn hellotest(ctx: &egui::Context) -> bool {
    let mut open = true;
    egui::Window::new("hello there")
        .open(&mut open)
        .show(ctx, |ui| {
            if ui.button("hello").clicked() {
                println!("hai");
            }
        });

    !open
}

struct MenuManager(pub HashMap<u8, Menu>, u8);

impl MenuManager {
    pub fn new() -> Self {
        Self {
            0: HashMap::new(),
            1: 0,
        }
    }

    pub fn add(&mut self, new: Menu) {
        self.0.insert(self.1, new);
        self.1 = self.1.wrapping_add(1);
    }
}
